Motor GridFS Classes
====================

.. currentmodule:: motor

Store blobs of data in `GridFS <http://docs.mongodb.org/manual/applications/gridfs/>`_.

.. seealso:: :ref:`Differences between PyMongo's and Motor's GridFS APIs
  <gridfs-differences>`.

.. seealso:: :doc:`web`

.. autoclass:: MotorGridFS
  :members:


.. autoclass:: MotorGridIn
  :members:

  .. autoattribute:: _id
  .. automethod:: set


.. autoclass:: MotorGridOut
  :members:

  .. autoattribute:: _id
